@@ -504,12 +504,18 @@ def test_get_updated_repo__repo_dne__kwargs_passed_to_clone_from(mocker, tmp_pat
 
     clone_from_mock = mocker.patch("pygitops.operations.Repo.clone_from")
 
-    some_kwargs = {"some_arg": "some-value", "another_arg": "another-value"}
+    some_kwargs = {
+        "some_arg": "some-value",
+        "another_arg": "another-value",
+        "force": True,
+    }
 
     get_updated_repo(SOME_CLONE_REPO_URL, tmp_path, **some_kwargs)
 
     clone_from_mock.assert_called_once_with(
-        SOME_CLONE_REPO_URL, tmp_path, **some_kwargs
+        SOME_CLONE_REPO_URL,
+        tmp_path,
+        **{"some_arg": "some-value", "another_arg": "another-value"},
     )
 
 
@@ -531,8 +537,12 @@ def test_get_updated_repo__repo_exists_locally__repo_update_performed_against_de
     repo_mock.remotes.origin.pull.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "force",
+    [True, False],
+)
 def test_get_updated_repo__repo_exists_locally__repo_update_performed_against_provided_branch(
-    mocker, tmp_path
+    mocker, tmp_path, force
 ):
 
     repo_mock = mocker.Mock()
@@ -543,10 +553,14 @@ def test_get_updated_repo__repo_exists_locally__repo_update_performed_against_pr
     )
     mocker.patch("pygitops.operations.Repo", return_value=repo_mock)
 
-    get_updated_repo(SOME_CLONE_REPO_URL, tmp_path, branch=SOME_FEATURE_BRANCH)
+    get_updated_repo(
+        SOME_CLONE_REPO_URL, tmp_path, branch=SOME_FEATURE_BRANCH, force=force
+    )
 
     get_default_branch_mock.assert_not_called()
-    _checkout_pull_branch_mock.assert_called_once_with(repo_mock, SOME_FEATURE_BRANCH)
+    _checkout_pull_branch_mock.assert_called_once_with(
+        repo_mock, SOME_FEATURE_BRANCH, force=force
+    )
 
 
 def test_get_updated_repo__clone_dirs_dne__clone_dirs_created(mocker, tmp_path):
@@ -710,9 +724,13 @@ def test_get_default_branch__match_index_error__raises_pygitops_error(mocker):
         get_default_branch(repo_mock)
 
 
-def test_get_default_branch__default_branch_returned(tmp_path):
+@pytest.mark.parametrize(
+    "branch_name",
+    ["main", "master", "2.x", "name-with-dashes", "name_with_underscores"],
+)
+def test_get_default_branch__default_branch_returned(tmp_path, branch_name):
 
-    repos = _initialize_multiple_empty_repos(tmp_path)
+    repos = _initialize_multiple_empty_repos(tmp_path, initial_branch=branch_name)
     remote_repo = repos.remote_repo
     local_repo = repos.local_repo
 
@@ -742,7 +760,7 @@ def _initialize_repo_with_content(repo_path):
     """
 
     repo_path.mkdir()
-    repo = Repo.init(repo_path)
+    repo = Repo.init(repo_path, initial_branch=GIT_BRANCH_MASTER)
 
     _commit_content(repo, SOME_INITIAL_CONTENT, commit_message="Initial commit")
 
@@ -823,7 +841,9 @@ def _assert_branch_state_stage_commit_push_changes__file_removed(
 
 
 # Helper functions for testing git operations
-def _initialize_multiple_empty_repos(base_path) -> MultipleTestingRepos:
+def _initialize_multiple_empty_repos(
+    base_path, initial_branch="main"
+) -> MultipleTestingRepos:
     """
     Helper function used to initialize and configure local, remote, and clone repos for integration testing.
     """
@@ -840,7 +860,7 @@ def _initialize_multiple_empty_repos(base_path) -> MultipleTestingRepos:
     clone_path.mkdir()
 
     # The remote is set up as a bare repository
-    remote_repo = Repo.init(remote_path)
+    remote_repo = Repo.init(remote_path, initial_branch=initial_branch)
 
     # give the remote repo some initial commit history
     new_file_path = remote_path / SOME_CONTENT_FILENAME
